<?php // Simple Download Counter - Shortcodes

if (!defined('ABSPATH')) exit;


function simple_download_counter_downloads_published($atts) {
	
	$count = (int) wp_count_posts('sdc_download')->publish;
	
	return is_int($count) ? number_format($count) : 0;
	
}

function simple_download_counter_count_total($atts) {
	
	$count = 0;
	
	$args = array('post_type' => 'sdc_download', 'posts_per_page' => -1, 'post_status' => 'publish');
	
	$downloads = new WP_Query($args);
	
	while ($downloads->have_posts()) : 
		
		$downloads->the_post();
		
		$download_count = (int) get_post_meta(get_the_ID(), 'sdc_download_count', true);
		
		$count += is_int($download_count) ? (int) $download_count : 0;
		
	endwhile;
	
	return number_format($count);
	
}


//


function simple_download_counter_download($atts) {
	
	extract(shortcode_atts(array(
		
		'id'     => null, // required
		
		'wrap'   => 'p', // p, div, span, none
		'text'   => '%title%',
		'title'  => '%count% '. __('downloads', 'simple-download-counter'),
		'class'  => '',
		
		'before' => '',
		'after'  => '',
		
	), $atts, 'sdc_download'));
	
	if (empty($id) || !is_numeric($id)) {
		
		return __('Invalid Download ID', 'simple-download-counter');
		
	}
	
	//
	
	$array = array('text' => $text, 'title' => $title, 'before' => $before, 'after' => $after);
	
	list($array, $text, $title, $before, $after, $download_url) = simple_download_counter_download_vars($id, $array);
	
	//
	
	if ($class) {
		
		$classes = '';
		
		$class = array_map('trim', explode(',', $class));
		
		foreach ($class as $key => $value) $classes .= ' '. sanitize_html_class($value);
		
		$class = $classes;
		
	}
	
	//
	
	$output = '';
	
	if ($wrap === 'p') {
		
		$output .= '<p id="simple-download-counter-'. esc_attr($id) .'" class="simple-download-counter'. $class .'">';
		
	} elseif ($wrap === 'div') {
		
		$output .= '<div id="simple-download-counter-'. esc_attr($id) .'" class="simple-download-counter'. $class .'">';
		
	} elseif ($wrap === 'span') {
		
		$output .= '<span id="simple-download-counter-'. esc_attr($id) .'" class="simple-download-counter'. $class .'"">';
		
	}
	
	$output .= $before .'<a class="simple-download-counter-link" href="'. esc_url($download_url) .'" title="'. esc_attr($title) .'">'. $text .'</a>'. $after;
	
	if ($wrap === 'p') {
		
		$output .= '</p>';
		
	} elseif ($wrap === 'div') {
		
		$output .= '</div>';
		
	} elseif ($wrap === 'span') {
		
		$output .= '</span>';
		
	}
	
	return $output;
	
}


function simple_download_counter_props($id) {
	
	$download = get_post(absint($id));
	
	$download_title = $download->post_title;
	
	$download_url     = simple_download_counter_download_url($id);
	$download_count   = simple_download_counter_get_count($id);
	$download_version = simple_download_counter_get_version($id);
	$download_type    = simple_download_counter_get_type($id);
	$download_ext     = simple_download_counter_get_ext($id);
	$download_size    = simple_download_counter_get_size($id);
	
	return array($download_title, $download_url, $download_count, $download_version, $download_type, $download_ext, $download_size);
		
}


function simple_download_counter_download_vars($id, $array) {
	
	list($download_title, $download_url, $download_count, $download_version, $download_type, $download_ext, $download_size) = simple_download_counter_props($id);
	
	foreach ($array as $key => $value) {
		
		if ($key === 'text' || $key === 'title') {
			
			$array[$key] = str_replace('%id%',      $id,                            $array[$key]);
			$array[$key] = str_replace('%title%',   $download_title,                $array[$key]);
			$array[$key] = str_replace('%version%', $download_version,              $array[$key]);
			$array[$key] = str_replace('%type%',    ucfirst($download_type),        $array[$key]);
			$array[$key] = str_replace('%ext%',     strtoupper($download_ext),      $array[$key]);
			$array[$key] = str_replace('%count%',   number_format($download_count), $array[$key]);
			$array[$key] = str_replace('%size%',    $download_size,                 $array[$key]);
			
		} else {
			
			$array[$key] = str_replace('%id%',      '<span class="simple-download-counter-id">'.      $id                            .'</span>', $array[$key]);
			$array[$key] = str_replace('%title%',   '<span class="simple-download-counter-title">'.   $download_title                .'</span>', $array[$key]);
			$array[$key] = str_replace('%version%', '<span class="simple-download-counter-version">'. $download_version              .'</span>', $array[$key]);
			$array[$key] = str_replace('%type%',    '<span class="simple-download-counter-type">'.    ucfirst($download_type)        .'</span>', $array[$key]);
			$array[$key] = str_replace('%ext%',     '<span class="simple-download-counter-ext">'.     strtoupper($download_ext)      .'</span>', $array[$key]);
			$array[$key] = str_replace('%count%',   '<span class="simple-download-counter-count">'.   number_format($download_count) .'</span>', $array[$key]);
			$array[$key] = str_replace('%size%',    '<span class="simple-download-counter-size">'.    $download_size                 .'</span>', $array[$key]);
			
		}
		
	}
	
	$text   = isset($array['text'])   ? $array['text']  : '';
	
	$title  = isset($array['title'])  ? $array['title'] : '';
	
	$before = (isset($array['before']) && !empty($array['before'])) ? '<span class="simple-download-counter-before">'. $array['before'] .'</span>' : '';
	
	$after  = (isset($array['after'])  && !empty($array['after']))  ? '<span class="simple-download-counter-after">'.  $array['after']  .'</span>' : '';
	
	return array($array, $text, $title, $before, $after, $download_url);
	
}


function simple_download_counter_download_url($id) {
	
	$scheme = parse_url(get_option('home'), PHP_URL_SCHEME);
	
	$key = simple_download_counter_key();
	
	if (get_option('permalink_structure')) {
		
		$url = home_url('/' . $key . '/' . $id . '/', $scheme);
		
	} else {
		
		$url = add_query_arg($key, $id, home_url('', $scheme));
	
	}
	
	return apply_filters('simple_download_counter_get_url', esc_url_raw($url));
	
}


//


function simple_download_counter_count($atts) {
	
	extract(shortcode_atts(array(
		
		'id'     => null, // required
		
		'wrap'   => 'p', // p, div, span, none
		'class'  => '',
		
		'before' => '%title% - ',
		'after'  => ' '. esc_html__('Downloads', 'simple-download-counter'),
		
	), $atts, 'sdc_count'));
	
	if (empty($id) || !is_numeric($id)) {
		
		return __('Invalid Download ID', 'simple-download-counter');
		
	}
	
	//
	
	$array = array('before' => $before, 'after' => $after);
	
	list($array, $before, $after, $download_count) = simple_download_counter_count_vars($id, $array);
	
	//
	
	if ($class) {
		
		$classes = '';
		
		$class = array_map('trim', explode(',', $class));
		
		foreach ($class as $key => $value) $classes .= ' '. sanitize_html_class($value);
		
		$class = $classes;
		
	}
	
	//
	
	$output = '';
	
	if ($wrap === 'p') {
		
		$output .= '<p id="sdc-download-count-'. esc_attr($id) .'" class="sdc-download-count'. $class .'">';
		
	} elseif ($wrap === 'div') {
		
		$output .= '<div id="sdc-download-count-'. esc_attr($id) .'" class="sdc-download-count'. $class .'">';
		
	} elseif ($wrap === 'span') {
		
		$output .= '<span id="sdc-download-count-'. esc_attr($id) .'" class="sdc-download-count'. $class .'">';
		
	}
	
	$output .= $before .'<span class="sdc-count">'. number_format($download_count) .'</span>'. $after;
	
	if ($wrap === 'p') {
		
		$output .= '</p>';
		
	} elseif ($wrap === 'div') {
		
		$output .= '</div>';
		
	} elseif ($wrap === 'span') {
		
		$output .= '</span>';
		
	}
	
	return $output;
	
}


function simple_download_counter_count_vars($id, $array) {
	
	list($download_title, $download_url, $download_count, $download_version, $download_type, $download_ext, $download_size) = simple_download_counter_props($id);
	
	foreach ($array as $key => $value) {
		
		$array[$key] = str_replace('%id%',      '<span class="sdc-id">'      . $id                       .'</span>', $array[$key]);
		$array[$key] = str_replace('%title%',   '<span class="sdc-title">'   . $download_title           .'</span>', $array[$key]);
		$array[$key] = str_replace('%version%', '<span class="sdc-version">' . $download_version         .'</span>', $array[$key]);
		$array[$key] = str_replace('%type%',    '<span class="sdc-type">'    . ucfirst($download_type)   .'</span>', $array[$key]);
		$array[$key] = str_replace('%ext%',     '<span class="sdc-ext">'     . strtoupper($download_ext) .'</span>', $array[$key]);
		$array[$key] = str_replace('%size%',    '<span class="sdc-size">'    . $download_size            .'</span>', $array[$key]);
		
	}
	
	$before = (isset($array['before']) && !empty($array['before'])) ? '<span class="sdc-before">'. $array['before'] .'</span>' : '';
	
	$after  = (isset($array['after'])  && !empty($array['after']))  ? '<span class="sdc-after">'.  $array['after']  .'</span>' : '';
	
	return array($array, $before, $after, $download_count);
	
}


//


function simple_download_counter_add_mce_plugin($plugins) {
	
	$plugins['sdc_download'] = DOWNLOAD_COUNTER_URL .'js/tinymce.js';
	
	return $plugins;
	
}


function simple_download_counter_add_mce_button($buttons) {
	
	array_push($buttons, 'sdc_download');
	
	return $buttons;
	
}


function simple_download_counter_add_mce() {
	
	add_filter('mce_external_plugins', 'simple_download_counter_add_mce_plugin', 10);
	add_filter('mce_buttons',          'simple_download_counter_add_mce_button', 10);
	
}


function simple_download_counter_add_quicktags() {
	
	if (!function_exists('get_current_screen')) require_once ABSPATH .'/wp-admin/includes/screen.php';
	
	$screen = get_current_screen();
	
	if ($screen->base === 'post' && wp_script_is('quicktags')) : 
	
	// QTags.addButton(id, display, arg1, arg2, access_key, title, priority, instance);
	
	?>
	
	<script type="text/javascript">
		window.onload = function() {
			QTags.addButton('sdc_download', '&darr;', '[sdc_download id=""]', null, 'z', 'Add Download');
		};
	</script>
	
<?php endif;

}